@@ -226,8 +226,6 @@ module.exports = class Workspace extends Model {
     }
 
     this.incoming = new Map()
-
-    this.subscribeToEvents()
   }
 
   get paneContainer () {
@@ -317,9 +315,9 @@ module.exports = class Workspace extends Model {
     this.consumeServices(this.packageManager)
   }
 
-  subscribeToEvents () {
+  initialize () {
+    this.originalFontSize = this.config.get('editor.fontSize')
     this.project.onDidChangePaths(this.updateWindowTitle)
-    this.subscribeToFontSize()
     this.subscribeToAddedItems()
     this.subscribeToMovedItems()
     this.subscribeToDockToggling()
@@ -1548,14 +1546,6 @@ module.exports = class Workspace extends Model {
     }
   }
 
-  subscribeToFontSize () {
-    return this.config.onDidChange('editor.fontSize', () => {
-      if (this.originalFontSize == null) {
-        this.originalFontSize = this.config.get('editor.fontSize')
-      }
-    })
-  }
-
   // Removes the item's uri from the list of potential items to reopen.
   itemOpened (item) {
     let uri
